@@ -3,7 +3,7 @@
 //  $Id: $
 //
 //  Created by Jean-Etienne LAMIAUD on Thu Feb 14 2023.
-//  Copyright (c) 2023. Jean-Etienne LAMIAUD
+//  Copyright (c) 2023-2025. Jean-Etienne LAMIAUD
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -376,6 +376,52 @@ const NSString *BayerProcessedDarktKey = @"procDark";
    return(self);
 }
 
+- (void) processAsDarkFrame
+{
+   if (!_isProcessedDark)
+   {
+      // Weight will be substracted during calibration, therefore, set all weight to zero, except for dead pixels
+      // Start by getting mean and standard deviation of pixels in the bayer matrix
+      u_short c, x, y;
+      double s = 0.0, s2 = 0.0, n = 0.0;
+      for (y = 0; y < _h; y++)
+      {
+         for (x = 0; x < _w; x++)
+         {
+            for (c = 0; c < _nPlanes; c++)
+            {
+               double w = stdColorValue(_weight, x, y, c);
+               double v = w*stdColorValue(self, x, y, c);
+               s += v;
+               s2 += v*v;
+               n += w;
+            }
+         }
+      }
+      double mean = s/n;
+      double sigma = sqrt(s2/n - mean*mean);
+      for (y = 0; y < _h; y++)
+      {
+         for (x = 0; x < _w; x++)
+         {
+            for (c = 0; c < _nPlanes; c++)
+            {
+               if (stdColorValue(_weight, x, y, c) <= 0.0
+                   || (stdColorValue(self, x, y, c) - mean) < 3.0*sigma)
+                  // Correct pixel, weight shall not change in calibrated image
+                  stdColorValue(_weight, x, y, c) = 0.0;
+               // Otherwise, it is a dead pixel, keep the weight, in order to null it in the  calibrated image
+               //               else
+               //                  NSLog(@"Dead pixel at %d,%d in plane %d, value %f weight %f",
+               //                        x, y, c, stdColorValue(_darkFrame, x, y, c),
+               //                        stdColorValue(_weight, x, y, c));
+            }
+         }
+      }
+      _isProcessedDark = YES;
+   }
+}
+
 - (nullable instancetype) initWithCoder:(nonnull NSCoder *)aDecoder
 {
    if ((self = [super initWithCoder:aDecoder]) != nil)
