@@ -3,7 +3,7 @@
 //  $Id$
 //
 //  Created by Jean-Etienne LAMIAUD on Wed Apr 27 2005.
-//  Copyright (c) 2005-2023. Jean-Etienne LAMIAUD
+//  Copyright (c) 2005-2025. Jean-Etienne LAMIAUD
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -806,7 +806,7 @@ static BOOL isWaitingConversion = NO;
 
 - (void) setDarkFrame:(LynkeosImageBuffer*)dark
 {
-   NSAssert( dark == nil || _mode == ImageMode || _mode == UnsetListMode,
+   NSAssert( dark == nil || _mode == ImageMode || _mode == UnsetListMode || _mode == FlatFieldMode,
              @"Inconsistent combination of image mode and calibration frames" );
 
    _dark = dark;
