@@ -3,7 +3,7 @@
 //  $Id$
 //
 //  Created by Jean-Etienne LAMIAUD on Sat Aug 11 2007.
-//  Copyright (c) 2007-2023. Jean-Etienne LAMIAUD
+//  Copyright (c) 2007-2025. Jean-Etienne LAMIAUD
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -280,7 +280,8 @@ static NSString * const K_PLANELEVELS_SET_KEY = @"planeLevelsSet";
    if ( _processedSpectrum != nil )
       [self goIntoImageSpace];
 
-   if ( _processedImage != nil && _white[_nPlanes] > _black[_nPlanes] )
+   if ( _processedImage != nil && _white != NULL && _black != NULL
+        && _white[_nPlanes] > _black[_nPlanes] )
       image = [_processedImage getImageInRect:LynkeosIntegerRectFromNSRect(rect)
                                     withBlack:_black white:_white gamma:_gamma];
 
