@@ -3,7 +3,7 @@
 //  $Id$
 //
 //  Created by Jean-Etienne LAMIAUD on Thu Jul 29 2004.
-//  Copyright (c) 2004-2020. Jean-Etienne LAMIAUD
+//  Copyright (c) 2004-2025. Jean-Etienne LAMIAUD
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -32,6 +32,7 @@
 #include "LynkeosImageBufferAdditions.h"
 #include "LynkeosBasicAlignResult.h"
 #include "MyCustomAlert.h"
+#include "LynkeosAlertPanel.h"
 #include "MyImageListWindow.h" // Only for allocation purpose
 
 #include "MyDocument.h"
@@ -44,6 +45,8 @@
 
 #define K_DOCUMENT_TYPE		@"Lynkeos project"
 
+enum {ThreadsIdle, ThreadsStarted};
+
 // A bad hack for relative URL resolution (until I find a better solution)
 NSString *basePath = nil;
 
@@ -129,6 +132,7 @@ static void MySleepCallBack(void * x, io_service_t y, natural_t messageType,
    // Connect the parameters chain
    [_imageList setParametersParent:_parameters];
    [_darkFrameList setParametersParent:_parameters];
+   [_flatDarkList setParametersParent:_parameters];
    [_flatFieldList setParametersParent:_parameters];
 
    // Initialize dark frame and flat field alignment to no offset
@@ -136,7 +140,9 @@ static void MySleepCallBack(void * x, io_service_t y, natural_t messageType,
                            [[[LynkeosBasicAlignResult alloc] init] autorelease];
    [_darkFrameList setProcessingParameter:r withRef:LynkeosAlignResultRef 
                             forProcessing:LynkeosAlignRef];      
-   [_flatFieldList setProcessingParameter:r withRef:LynkeosAlignResultRef 
+   [_flatDarkList setProcessingParameter:r withRef:LynkeosAlignResultRef
+                            forProcessing:LynkeosAlignRef];
+   [_flatFieldList setProcessingParameter:r withRef:LynkeosAlignResultRef
                             forProcessing:LynkeosAlignRef];
    [self updateChangeCount:NSChangeCleared];
 }
@@ -163,8 +169,14 @@ static void MySleepCallBack(void * x, io_service_t y, natural_t messageType,
    NSAssert( enumerator != nil || item != nil,
              @"Cannot start a process for nothing" );
 
-   NSAssert( [_threads count] == 0, 
-             @"Trying to start a process while one is already running" );
+   [_threadsLock lock];
+   if( [_threads count] != 0)
+   {
+      NSLog(@"Trying to start a process while one is already running");
+      [_threadsLock unlock];
+      return;
+   }
+   [_threadsLock unlock];
 
    // Start the process according to user preferences
    nListThreads = 1;
@@ -183,16 +195,18 @@ static void MySleepCallBack(void * x, io_service_t y, natural_t messageType,
    // Create the required number of processing threaded object
    for( i = 0; i < nListThreads; i++ )
    {
-      NSMutableDictionary *attrib = 
-                                 [NSMutableDictionary dictionaryWithCapacity:4];
-
       ThreadControl *thr = [[[ThreadControl alloc] init] autorelease];
-      [_threads addObject:thr];
 
       thr->_cnx = [[LynkeosThreadConnection alloc] initWithMainPort:_threadsPort
                                                          threadPort:[NSPort port]];
       [thr->_cnx setRootObject:self];
 
+      [_threadsLock lock];
+      [_threads addObject:thr];
+      [_threadsLock unlock];
+
+      NSMutableDictionary *attrib = [NSMutableDictionary dictionaryWithCapacity:4];
+
       // Give attributes to the thread controller
       [attrib setObject:thr->_cnx forKey: K_PROCESS_CONNECTION];
       [attrib setObject:processingClass forKey: K_PROCESS_CLASS_KEY];
@@ -207,6 +221,8 @@ static void MySleepCallBack(void * x, io_service_t y, natural_t messageType,
                                toTarget:[MyProcessingThread class]
                              withObject:attrib];
    }
+   [_threadsLock lock];
+   [_threadsLock unlockWithCondition:ThreadsStarted];
 }
 
 - (BOOL) continueProcessing
@@ -270,6 +286,7 @@ static void MySleepCallBack(void * x, io_service_t y, natural_t messageType,
    {
       _imageList = [[MyImageList imageListWithArray:nil] retain];
       _darkFrameList = [[MyImageList imageListWithArray:nil] retain];
+      _flatDarkList = [[MyImageList imageListWithArray:nil] retain];
       _flatFieldList = [[MyImageList imageListWithArray:nil] retain];
       _currentList = _imageList;
       _dataMode = ListData;
@@ -279,6 +296,7 @@ static void MySleepCallBack(void * x, io_service_t y, natural_t messageType,
 
       _threadsPort = [[NSPort port] retain];
       _threads = [[NSMutableArray array] retain];
+      _threadsLock = [[NSConditionLock alloc] initWithCondition:ThreadsIdle];
       _currentProcessingClass = nil;
       _processedItem = nil;
       _processStackMgr = [[ProcessStackManager alloc] init];
@@ -327,6 +345,7 @@ static void MySleepCallBack(void * x, io_service_t y, natural_t messageType,
    [_myWindow release];
    [_imageList release];
    [_darkFrameList release];
+   [_flatDarkList release];
    [_flatFieldList release];
    [_calibrationLock release];
    [_processStackMgr release];
@@ -335,6 +354,7 @@ static void MySleepCallBack(void * x, io_service_t y, natural_t messageType,
 
    [_threadsPort release];
    [_threads release];
+   [_threadsLock release];
 
    [_parameters release];
 
@@ -344,23 +364,18 @@ static void MySleepCallBack(void * x, io_service_t y, natural_t messageType,
 //==============================================================================
 // Document load and save
 //==============================================================================
-// The method is deprecated, but saveToURL:ofType:forSaveOperation:completionHandler: is not supported
-// on 10.6. Therefore, wait until it is removed to leave 10.6 aside
-- (BOOL)saveToURL:(NSURL *)absoluteURL ofType:(NSString *)typeName
- forSaveOperation:(NSSaveOperationType)saveOperation error:(NSError **)outError
+- (void) saveToURL:(NSURL *)url ofType:(NSString *)typeName forSaveOperation:(NSSaveOperationType)saveOperation
+ completionHandler:(void (^)(NSError * _Nullable))completionHandler
 {
    // A bad hack for relative URL resolution (until I find a better solution)
-    if ( saveOperation != NSAutosaveOperation )
-      basePath = [[absoluteURL path] stringByDeletingLastPathComponent];
+    if ( saveOperation != NSAutosaveElsewhereOperation )
+      basePath = [[url path] stringByDeletingLastPathComponent];
    else
       basePath = nil;
 
-   BOOL res = [super saveToURL:absoluteURL ofType:typeName
-              forSaveOperation:saveOperation error:outError];
+   [super saveToURL:url ofType:typeName forSaveOperation:saveOperation completionHandler:completionHandler];
 
    basePath = nil;
-
-   return( res );
 }
 
 - (BOOL) readFromURL:(NSURL *)absoluteURL ofType:(NSString *)typeName error:(NSError **)outError
@@ -370,9 +385,8 @@ static void MySleepCallBack(void * x, io_service_t y, natural_t messageType,
    // if the absolute URL read did fail.
    basePath = [[absoluteURL path] stringByDeletingLastPathComponent];
 
-   NSFileWrapper *wrap =
-          [[[NSFileWrapper alloc] initWithPath:[absoluteURL path]] autorelease];
-   BOOL res = [self readFromFileWrapper:wrap ofType:typeName error:outError];
+   NSFileWrapper *wrap = [[[NSFileWrapper alloc] initWithURL:absoluteURL options:0 error:outError] autorelease];
+   BOOL res = (*outError == nil) && [self readFromFileWrapper:wrap ofType:typeName error:outError];
 
    basePath = nil;
 
@@ -388,6 +402,7 @@ static void MySleepCallBack(void * x, io_service_t y, natural_t messageType,
    myData = [[[MyDocumentDataV2 alloc] init] autorelease];
    myData->_imageList = _imageList;
    myData->_darkFrameList = _darkFrameList;
+   myData->_flatDarkList = _flatDarkList;
    myData->_flatFieldList = _flatFieldList;
    myData->_windowSizes = [_myWindow windowSizes];
    myData->_parameters = [_parameters getDictionary];
@@ -422,17 +437,23 @@ static void MySleepCallBack(void * x, io_service_t y, natural_t messageType,
          MyDocumentDataV2 *myV2Data = (MyDocumentDataV2*)myData;
 
          if ( myV2Data->_formatRevision != K_DATA_REVISION )
-            NSRunAlertPanel(NSLocalizedString(@"DeprecatedFormat",
-                                              @"Deprecated format alert panel title"),
-                            NSLocalizedString(@"DeprecatedFormatText",
-                                              @"Deprecated format text"),
-                            nil, nil, nil );
+            [LynkeosAlertPanel runAlertWithTitle:NSLocalizedString(@"DeprecatedFormat",
+                                                                   @"Deprecated format alert panel title")
+                                           style:NSAlertStyleCritical
+                                         message:NSLocalizedString(@"DeprecatedFormatText",
+                                                                   @"Deprecated format text")];
 
-         [_imageList release];
+         if (_imageList != nil)
+            [_imageList release];
          _imageList = myV2Data->_imageList;
-         [_darkFrameList release];
+         if (_darkFrameList != nil)
+            [_darkFrameList release];
          _darkFrameList = myV2Data->_darkFrameList;
-         [_flatFieldList release];
+         if (_flatDarkList != nil)
+            [_flatDarkList release];
+         _flatDarkList = myV2Data->_flatDarkList;
+         if (_flatFieldList != nil)
+            [_flatFieldList release];
          _flatFieldList = myV2Data->_flatFieldList;
 
          [_parameters setDictionary:myV2Data->_parameters];
@@ -461,9 +482,11 @@ static void MySleepCallBack(void * x, io_service_t y, natural_t messageType,
          if ( list == _imageList )
             list = _darkFrameList;
          else if ( list == _darkFrameList )
+            list = _flatDarkList;
+         else if ( list == _flatDarkList )
             list = _flatFieldList;
-            else
-         list = nil;
+         else
+            list = nil;
       }
 
       // If some items could not be initialized, remove them from the document
@@ -477,13 +500,13 @@ static void MySleepCallBack(void * x, io_service_t y, natural_t messageType,
          while ( (item = [files nextObject]) != nil )
          {
             [message appendFormat:@"\n%@",
-                              [[[item getURL] absoluteString]
-                                   stringByReplacingPercentEscapesUsingEncoding:
-                                                         NSUTF8StringEncoding]];
+                              [[[item getURL] absoluteString] stringByRemovingPercentEncoding]];
             if ( [[_imageList imageArray] containsObject:item] )
                [_imageList deleteItem:item];
             else if ( [[_darkFrameList imageArray] containsObject:item] )
                [_darkFrameList deleteItem:item];
+            else if ( [[_flatDarkList imageArray] containsObject:item] )
+               [_flatDarkList deleteItem:item];
             else if ( [[_flatFieldList imageArray] containsObject:item] )
                [_flatFieldList deleteItem:item];
          }
@@ -514,8 +537,7 @@ static void MySleepCallBack(void * x, io_service_t y, natural_t messageType,
       }
 
       for ( list = _darkFrameList;
-            list != nil ; 
-            list = (list == _darkFrameList ? _flatFieldList : nil) )
+            list != nil ; )
       {
          files = [[list imageArray] objectEnumerator];
          [lostFiles removeAllObjects];
@@ -524,6 +546,8 @@ static void MySleepCallBack(void * x, io_service_t y, natural_t messageType,
             BOOL success;
             if ( list == _darkFrameList )
                success = [_calibrationLock addDarkFrameItem:item];
+            else if ( list == _flatDarkList )
+               success = [_calibrationLock addFlatDarkItem: item];
             else
                success = [_calibrationLock addFlatFieldItem:item];
             if ( !success )
@@ -541,6 +565,13 @@ static void MySleepCallBack(void * x, io_service_t y, natural_t messageType,
             while ( (item = [files nextObject]) != nil )
                [list deleteItem: item];
          }
+
+         if ( list == _darkFrameList )
+            list = _flatDarkList;
+         else if ( list == _flatDarkList )
+            list = _flatFieldList;
+         else
+            list = nil;
       }
       // Notify of the load
       [_myWindow documentDidLoad:self]; // The window controller first
@@ -591,6 +622,7 @@ static void MySleepCallBack(void * x, io_service_t y, natural_t messageType,
 //==============================================================================
 - (id <LynkeosImageList>) imageList { return( _imageList ); }
 - (id <LynkeosImageList>) darkFrameList { return( _darkFrameList ); }
+- (id <LynkeosImageList>) flatDarkList { return _flatDarkList; }
 - (id <LynkeosImageList>) flatFieldList { return( _flatFieldList ); }
 - (id <LynkeosImageList>) currentList { return( _currentList ); }
 - (NSDictionary*) savedWindowSizes { return( _windowSizes ); }
@@ -601,6 +633,8 @@ static void MySleepCallBack(void * x, io_service_t y, natural_t messageType,
       return( ImageMode );
    else if ( _currentList == _flatFieldList )
       return( FlatFieldMode );
+   else if ( _currentList == _flatDarkList )
+      return FlatDarkMode;
    else if ( _currentList == _darkFrameList )
       return( DarkFrameMode );
    else
@@ -626,6 +660,9 @@ static void MySleepCallBack(void * x, io_service_t y, natural_t messageType,
       case FlatFieldMode:
          _currentList = _flatFieldList;
          break;
+      case FlatDarkMode:
+         _currentList = _flatDarkList;
+         break;
       case DarkFrameMode:
          _currentList = _darkFrameList;
          break;
@@ -671,11 +708,11 @@ static void MySleepCallBack(void * x, io_service_t y, natural_t messageType,
          // Check for possible add of an image item
          if ( ! [_calibrationLock addImageItem:item] )
          {
-            NSRunAlertPanel(NSLocalizedString(@"CannotAddTitle",
-                                              @"Cannot add alert panel title"),
-                            NSLocalizedString(@"CannotAddText",
-                                              @"Cannot add alert panel text"),
-                            nil, nil, nil );
+            [LynkeosAlertPanel runAlertWithTitle:NSLocalizedString(@"CannotAddTitle",
+                                                                   @"Cannot add alert panel title")
+                                           style:NSAlertStyleCritical
+                                         message:NSLocalizedString(@"CannotAddText",
+                                                                   @"Cannot add alert panel text")];
             return;
          }
       }
@@ -685,15 +722,17 @@ static void MySleepCallBack(void * x, io_service_t y, natural_t messageType,
          BOOL success;
          if ( _currentList == _darkFrameList )
             success = [_calibrationLock addDarkFrameItem:item];
+         else if ( _currentList == _flatDarkList )
+            success = [_calibrationLock addFlatDarkItem: item];
          else
             success = [_calibrationLock addFlatFieldItem:item];
          if ( !success )
          {
-            NSRunAlertPanel(NSLocalizedString(@"CannotLockTitle",
-                                              @"Cannot lock alert panel title"),
-                            NSLocalizedString(@"CannotLockText",
-                                              @"Cannot lock alert panel text"),
-                            nil, nil, nil );
+            [LynkeosAlertPanel runAlertWithTitle:NSLocalizedString(@"CannotLockTitle",
+                                                                   @"Cannot lock alert panel title")
+                                           style:NSAlertStyleCritical
+                                         message:NSLocalizedString(@"CannotLockText",
+                                                                   @"Cannot lock alert panel text")];
             return;
          }
       }
@@ -733,6 +772,25 @@ static void MySleepCallBack(void * x, io_service_t y, natural_t messageType,
                      NSLocalizedString(@"Delete image",@"Delete image action")];
 
    [_currentList deleteItem:item];
+   // If this led to deletion of a calibration stack, remove it from the light parameters
+   if ([_currentList getOriginalImage] == nil)
+   {
+      if (_currentList == _darkFrameList)
+      {
+         [_imageList setProcessingParameter:nil withRef:myImageListItemDarkFrame
+                              forProcessing:nil];
+      }
+      else if (_currentList == _flatDarkList)
+      {
+         [_flatDarkList setProcessingParameter:nil withRef:myImageListItemDarkFrame
+                                 forProcessing:nil];
+      }
+      else if (_currentList == _flatFieldList)
+      {
+         [_imageList setProcessingParameter:nil withRef:myImageListItemFlatField
+                              forProcessing:nil];
+      }
+   }
 
    // Remove it from the calibration lock
    [_calibrationLock removeItem:item];
@@ -811,9 +869,11 @@ static void MySleepCallBack(void * x, io_service_t y, natural_t messageType,
    ThreadControl *thr;
 
    // Find which thread it is
+   [_threadsLock lock];
    threadList = [_threads objectEnumerator];
    while( (thr = [threadList nextObject]) != nil && thr->_cnx != cnx )
       ;
+   [_threadsLock unlock];
    NSAssert( thr != nil, @"Unknown created thread" );
 
    // Keep a reference on the new threaded object proxy
@@ -825,9 +885,11 @@ static void MySleepCallBack(void * x, io_service_t y, natural_t messageType,
    NSEnumerator *threadList;
    ThreadControl *thr;
 
+   [_threadsLock lock];
    threadList = [_threads objectEnumerator];
    while( (thr = [threadList nextObject]) != nil )
       [thr->_threaded stopProcessing];
+   [_threadsLock unlock];
 }
 
 - (oneway void) processEnded: (id)obj
@@ -836,17 +898,24 @@ static void MySleepCallBack(void * x, io_service_t y, natural_t messageType,
    ThreadControl *thr;
 
    // Find which thread it is
+   [_threadsLock lock];
    threadList = [_threads objectEnumerator];
    while( (thr = [threadList nextObject]) != nil && thr->_threaded != obj )
       ;
+   [_threadsLock unlock];
    NSAssert( thr != nil, @"Unknown finishing thread" );
 
    // Remove that thread from the list
+   [_threadsLock lockWhenCondition:ThreadsStarted];
    [_threads removeObject:thr];
 
    // Check if all threads have finished working
-   if ( [_threads count] == 0 )
+   if ( [_threads count] != 0 )
+      [_threadsLock unlock];
+   else
    {
+      [_threadsLock unlockWithCondition:ThreadsIdle];
+
       BOOL listProcessing = YES;
 
       // Notify of processing end
@@ -897,7 +966,8 @@ static void MySleepCallBack(void * x, io_service_t y, natural_t messageType,
 
 #if !defined GNUSTEP
       // Wake up the screen if needed
-      UpdateSystemActivity(HDActivity);
+      IOPMAssertionID assertionId;
+      IOPMAssertionDeclareUserActivity(CFSTR("Lynkeos"), kIOPMUserActiveLocal, &assertionId);
 #endif
 
       if (listProcessing )
