@@ -718,6 +718,7 @@ static NSMutableDictionary *monitorDictionary = nil;
       _numberOfSquares = 0;
       _sideMenuLimit = -1;
       _isAligning = NO;
+      _isActive = NO;
 
       // Prepare the table view cells
       _modifyButton = [[NSButtonCell alloc] initTextCell:@""];
@@ -886,6 +887,7 @@ static NSMutableDictionary *monitorDictionary = nil;
       // Stop receiving notifications
       [notifCenter removeObserver:self];
    }
+   _isActive = active;
 }
 
 - (LynkeosProcessingViewFrame_t) preferredDisplay { return( BottomTab ); }
@@ -1088,108 +1090,121 @@ static NSMutableDictionary *monitorDictionary = nil;
 dataCellForTableColumn:(NSTableColumn *)tableColumn
                   row:(NSInteger)row
 {
-   if ( tableColumn == nil )
-      return( nil );
-
-   id columnId = [tableColumn identifier];
-   MyImageAlignerListParametersV3 *listParams
+   if (_isActive)
+   {
+      if ( tableColumn == nil )
+         return( nil );
+      
+      id columnId = [tableColumn identifier];
+      MyImageAlignerListParametersV3 *listParams
       = [_list getProcessingParameterWithRef:myImageAlignerParametersRef
                                forProcessing:myImageAlignerRef];
-   SelectionIndex_t nSel = [listParams->_alignSquares count];
-   NSCell *modButton;
-   BOOL addOnly = NO;
-
-   // Adjust the button in the first column
-   if ( nSel == 0 )
-      // No selection at all, the only row is to fill the new selection
-      modButton = _emptyCell;
-
-   else
-   {
-      modButton = _modifyButton;
-      if ( (SelectionIndex_t)row < nSel )
-         // Existing selection, it's a delete button
-         [_modifyButton setTitle:@"-"];
-
+      SelectionIndex_t nSel = [listParams->_alignSquares count];
+      NSCell *modButton;
+      BOOL addOnly = NO;
+      
+      // Adjust the button in the first column
+      if ( nSel == 0 )
+         // No selection at all, the only row is to fill the new selection
+         modButton = _emptyCell;
+      
       else
       {
-         // Extra line, with only an add button
-         [_modifyButton setTitle:@"+"];
-         addOnly = YES;
+         modButton = _modifyButton;
+         if ( (SelectionIndex_t)row < nSel )
+            // Existing selection, it's a delete button
+            [_modifyButton setTitle:@"-"];
+         
+         else
+         {
+            // Extra line, with only an add button
+            [_modifyButton setTitle:@"+"];
+            addOnly = YES;
+         }
       }
+      
+      if ( [columnId isEqual:@"modify"] )
+         return( modButton );
+      
+      else if ( [columnId isEqual:@"x"] )
+         return( addOnly ? _emptyCell : _xField );
+      
+      else if ( [columnId isEqual:@"y"] )
+         return( addOnly ? _emptyCell : _yField );
+      
+      else if ( [columnId isEqual:@"size"] )
+         return( addOnly ? _emptyCell : _sizeField );
+      
+      else
+         return( nil );
    }
-
-   if ( [columnId isEqual:@"modify"] )
-      return( modButton );
-
-   else if ( [columnId isEqual:@"x"] )
-      return( addOnly ? _emptyCell : _xField );
-
-   else if ( [columnId isEqual:@"y"] )
-      return( addOnly ? _emptyCell : _yField );
-
-   else if ( [columnId isEqual:@"size"] )
-      return( addOnly ? _emptyCell : _sizeField );
-
    else
-      return( nil );
+      return nil;
 }
 
 - (BOOL)tableView:(NSTableView *)aTableView
 shouldEditTableColumn:(NSTableColumn *)aTableColumn
               row:(NSInteger)rowIndex
 {
-   id columnId = [aTableColumn identifier];
-   id <LynkeosProcessableItem> item = [_window highlightedItem];
-   MyImageAlignerImageParametersV3 *params
+   if (_isActive)
+   {
+      id columnId = [aTableColumn identifier];
+      id <LynkeosProcessableItem> item = [_window highlightedItem];
+      MyImageAlignerImageParametersV3 *params
       = [item getProcessingParameterWithRef:myImageAlignerParametersRef
                               forProcessing:myImageAlignerRef];
-
-   return( !_isAligning &&
-           (![params isMemberOfClass:[MyImageAlignerImageParametersV3 class]] ||
-            ![columnId isEqualToString:@"size"]) );
+      
+      return( !_isAligning &&
+             (![params isMemberOfClass:[MyImageAlignerImageParametersV3 class]] ||
+              ![columnId isEqualToString:@"size"]) );
+   }
+   else
+      return NO;
 }
 
 - (void)tableViewSelectionDidChange:(NSNotification *)aNotification
 {
-   // Make the new selection active
-   id <LynkeosProcessableItem> item = [_window highlightedItem];
-   MyImageAlignerListParametersV3 *listParams
+   if (_isActive)
+   {
+      // Make the new selection active
+      id <LynkeosProcessableItem> item = [_window highlightedItem];
+      MyImageAlignerListParametersV3 *listParams
       = [_list getProcessingParameterWithRef:myImageAlignerParametersRef
                                forProcessing:myImageAlignerRef];
-   MyImageAlignerImageParametersV3 *params
+      MyImageAlignerImageParametersV3 *params
       = [item getProcessingParameterWithRef:myImageAlignerParametersRef
                               forProcessing:myImageAlignerRef];
-   NSInteger index = [_squaresTable selectedRow];
-
-   if ( index >= 0 )
-   {
-      if ((SelectionIndex_t)index == [_imageView activeSelectionIndex] )
-         // No selection to update
-         return;
-
-      // A new line was selected, but watch out, there can be a line without
-      // any selection
-      if ( (NSUInteger)index < [listParams->_alignSquares count] )
+      NSInteger index = [_squaresTable selectedRow];
+      
+      if ( index >= 0 )
       {
-         MyImageAlignerSquareV3 *square
+         if ((SelectionIndex_t)index == [_imageView activeSelectionIndex] )
+            // No selection to update
+            return;
+         
+         // A new line was selected, but watch out, there can be a line without
+         // any selection
+         if ( (NSUInteger)index < [listParams->_alignSquares count] )
+         {
+            MyImageAlignerSquareV3 *square
             = [itemAlignSquares(item, listParams) objectAtIndex:index];
-         LynkeosIntegerRect r = {square->_alignOrigin, square->_alignSize};
-
-         [_imageView setSelection:r atIndex:index
-                        resizable:[params isMemberOfClass:
-                                       [MyImageAlignerImageParametersV3 class]]
-                          movable:YES];
+            LynkeosIntegerRect r = {square->_alignOrigin, square->_alignSize};
+            
+            [_imageView setSelection:r atIndex:index
+                           resizable:[params isMemberOfClass:
+                                      [MyImageAlignerImageParametersV3 class]]
+                             movable:YES];
+         }
+      }
+      else
+      {
+         SelectionIndex_t idx = [_imageView activeSelectionIndex];
+         // No line selected, set it to the the image active selection
+         if ( idx != NSNotFound )
+            [_squaresTable selectRowIndexes:
+             [NSIndexSet indexSetWithIndex:idx]
+                       byExtendingSelection:NO];
       }
-   }
-   else
-   {
-      SelectionIndex_t idx = [_imageView activeSelectionIndex];
-      // No line selected, set it to the the image active selection
-      if ( idx != NSNotFound )
-         [_squaresTable selectRowIndexes:
-                           [NSIndexSet indexSetWithIndex:idx]
-                    byExtendingSelection:NO];
    }
 }
 
@@ -1197,53 +1212,65 @@ shouldEditTableColumn:(NSTableColumn *)aTableColumn
 
 - (NSInteger)numberOfRowsInTableView:(NSTableView *)aTableView
 {
-   MyImageAlignerListParametersV3 *listParams = nil;
-   NSUInteger n;
-
-   if ( _list != nil )
-      listParams = [_list getProcessingParameterWithRef:myImageAlignerParametersRef
-                                          forProcessing:myImageAlignerRef];
-
-   if ( listParams != nil )
-      n = [listParams->_alignSquares count] + 1;
+   if (_isActive)
+   {
+      MyImageAlignerListParametersV3 *listParams = nil;
+      NSUInteger n;
+      
+      if ( _list != nil )
+         listParams = [_list getProcessingParameterWithRef:myImageAlignerParametersRef
+                                             forProcessing:myImageAlignerRef];
+      
+      if ( listParams != nil )
+         n = [listParams->_alignSquares count] + 1;
+      else
+         n = 0;
+      
+      return( n );
+   }
    else
-      n = 0;
-
-   return( n );
+      // Data source can be called when everything is not yet / still setup
+      return 0;
 }
 
 - (id)tableView:(NSTableView *)aTableView
 objectValueForTableColumn:(NSTableColumn *)aTableColumn
             row:(NSInteger)rowIndex
 {
-   id columnId = [aTableColumn identifier];
-   id <LynkeosProcessableItem> item = [_window highlightedItem];
-   MyImageAlignerListParametersV3 *listParams =
-                [_list getProcessingParameterWithRef:myImageAlignerParametersRef
-                                       forProcessing:myImageAlignerRef];
-   SelectionIndex_t nSel = [listParams->_alignSquares count];
-   MyImageAlignerSquareV3 *square = nil;
-
-   if ( nSel != 0 && rowIndex < (NSInteger)nSel )
-      square = [itemAlignSquares(item, listParams) objectAtIndex:rowIndex];
-
-   if ( [columnId isEqual:@"modify"] )
-      return( nSel != 0 ? [NSNumber numberWithInt:NSOffState] : nil );
-
-   else if ( [columnId isEqual:@"x"] )
-      return( square != nil ?
-             [NSNumber numberWithInt:square->_alignOrigin.x ] : nil );
-
-   else if ( [columnId isEqual:@"y"] )
-      return( square != nil ?
-             [NSNumber numberWithInt:square->_alignOrigin.y] : nil );
-
-   else if ( [columnId isEqual:@"size"] )
-      return( square != nil ?
-             [NSNumber numberWithInt:square->_alignSize.width] : nil);
-
+   if (_isActive)
+   {
+      id columnId = [aTableColumn identifier];
+      id <LynkeosProcessableItem> item = [_window highlightedItem];
+      MyImageAlignerListParametersV3 *listParams =
+      [_list getProcessingParameterWithRef:myImageAlignerParametersRef
+                             forProcessing:myImageAlignerRef];
+      SelectionIndex_t nSel = [listParams->_alignSquares count];
+      MyImageAlignerSquareV3 *square = nil;
+      
+      if ( nSel != 0 && rowIndex < (NSInteger)nSel )
+         square = [itemAlignSquares(item, listParams) objectAtIndex:rowIndex];
+      
+      if ( [columnId isEqual:@"modify"] )
+         return( nSel != 0 ? [NSNumber numberWithInt:NSOffState] : nil );
+      
+      else if ( [columnId isEqual:@"x"] )
+         return( square != nil ?
+                [NSNumber numberWithInt:square->_alignOrigin.x ] : nil );
+      
+      else if ( [columnId isEqual:@"y"] )
+         return( square != nil ?
+                [NSNumber numberWithInt:square->_alignOrigin.y] : nil );
+      
+      else if ( [columnId isEqual:@"size"] )
+         return( square != nil ?
+                [NSNumber numberWithInt:square->_alignSize.width] : nil);
+      
+      else
+         return( nil );
+   }
    else
-      return( nil );
+      // Data source can be called when everything is not yet / still setup
+      return nil;
 }
 
 - (void)tableView:(NSTableView *)aTableView
@@ -1251,115 +1278,118 @@ objectValueForTableColumn:(NSTableColumn *)aTableColumn
    forTableColumn:(NSTableColumn *)aTableColumn
               row:(NSInteger)rowIndex
 {
-   id columnId = [aTableColumn identifier];
-   id <LynkeosProcessableItem> item = [_window highlightedItem];
-   NSAssert(item != nil, @"No item to change the square");
-   MyImageAlignerImageParametersV3 *params =
-                 [item getProcessingParameterWithRef:myImageAlignerParametersRef
-                                       forProcessing:myImageAlignerRef];
-   MyImageAlignerListParametersV3 *listParams =
-                [_list getProcessingParameterWithRef:myImageAlignerParametersRef
-                                       forProcessing:myImageAlignerRef];
-   const NSInteger nSquares = (NSInteger)[listParams->_alignSquares count];
-   id <LynkeosProcessable> dest;
-   LynkeosIntegerRect r = {{0, 0}, {0, 0}};
-
-   NSAssert(rowIndex <= nSquares,
-            @"Selection index %ld is beyond bound %ld",
-            (long)rowIndex, (long)nSquares );
-
-   if ( rowIndex < nSquares )
-   {
-      MyImageAlignerSquareV3 *square
-         = [itemAlignSquares(item, listParams) objectAtIndex:rowIndex];
-      r.origin = square->_alignOrigin;
-      r.size = square->_alignSize;
-   }
-
-   if ( [columnId isEqualToString:@"modify"] )
+   if (_isActive)
    {
+      id columnId = [aTableColumn identifier];
+      id <LynkeosProcessableItem> item = [_window highlightedItem];
+      NSAssert(item != nil, @"No item to change the square");
+      MyImageAlignerImageParametersV3 *params =
+      [item getProcessingParameterWithRef:myImageAlignerParametersRef
+                            forProcessing:myImageAlignerRef];
+      MyImageAlignerListParametersV3 *listParams =
+      [_list getProcessingParameterWithRef:myImageAlignerParametersRef
+                             forProcessing:myImageAlignerRef];
+      const NSInteger nSquares = (NSInteger)[listParams->_alignSquares count];
+      id <LynkeosProcessable> dest;
+      LynkeosIntegerRect r = {{0, 0}, {0, 0}};
+      
+      NSAssert(rowIndex <= nSquares,
+               @"Selection index %ld is beyond bound %ld",
+               (long)rowIndex, (long)nSquares );
+      
       if ( rowIndex < nSquares )
-         // This is a deletion
-         [_imageView removeSelectionAtIndex:rowIndex];
-
-      else
       {
-         // This is an addition, use the same size as the last square
          MyImageAlignerSquareV3 *square
-            = [[listParams->_alignSquares objectAtIndex:rowIndex-1] copy];
-
-         square->_alignOrigin.x = 0;
-         square->_alignOrigin.y = 0;
-
-         [listParams->_alignSquares addObject:[square autorelease]];
-
-         // Add a NSNull at the end of all items with specific squares
-         NSEnumerator *items = [_list imageEnumeratorStartAt:nil
-                                                 directSense:NO
-                                              skipUnselected:NO];
-         while ( (item = [items nextObject]) != nil )
+         = [itemAlignSquares(item, listParams) objectAtIndex:rowIndex];
+         r.origin = square->_alignOrigin;
+         r.size = square->_alignSize;
+      }
+      
+      if ( [columnId isEqualToString:@"modify"] )
+      {
+         if ( rowIndex < nSquares )
+            // This is a deletion
+            [_imageView removeSelectionAtIndex:rowIndex];
+         
+         else
          {
-            params
+            // This is an addition, use the same size as the last square
+            MyImageAlignerSquareV3 *square
+            = [[listParams->_alignSquares objectAtIndex:rowIndex-1] copy];
+            
+            square->_alignOrigin.x = 0;
+            square->_alignOrigin.y = 0;
+            
+            [listParams->_alignSquares addObject:[square autorelease]];
+            
+            // Add a NSNull at the end of all items with specific squares
+            NSEnumerator *items = [_list imageEnumeratorStartAt:nil
+                                                    directSense:NO
+                                                 skipUnselected:NO];
+            while ( (item = [items nextObject]) != nil )
+            {
+               params
                = [item getProcessingParameterWithRef:myImageAlignerParametersRef
                                        forProcessing:myImageAlignerRef];
-
-            if ( [params isMemberOfClass:
-                            [MyImageAlignerImageParametersV3 class]] )
-               [params->_alignSquares addObject:[NSNull null]];
+               
+               if ( [params isMemberOfClass:
+                     [MyImageAlignerImageParametersV3 class]] )
+                  [params->_alignSquares addObject:[NSNull null]];
+            }
          }
+         // Parameter is not modified (it will be upon selection notification)
+         return;
       }
-      // Parameter is not modified (it will be upon selection notification)
-      return;
-   }
-
-   else if ( [columnId isEqualToString:@"x"] )
-      r.origin.x = [anObject intValue];
-
-   else if ( [columnId isEqualToString:@"y"] )
-      r.origin.y = [anObject intValue];
-
-   else if ( [columnId isEqualToString:@"size"] )
-   {
-      r.size.width = [anObject intValue];
-      r.size.height = r.size.width;
-   }
-
-   else
-      NSAssert( NO, @"Unexpected table view column in setObjectValue" );
-
-   if ( params != nil &&
-        [params isMemberOfClass:[MyImageAlignerImageParametersV3 class]] )
-   {
-      MyImageAlignerOriginV3 *o
-         = [[[MyImageAlignerOriginV3 alloc] init] autorelease];
-
-      o->_alignOrigin = r.origin;
-
-      [params->_alignSquares replaceObjectAtIndex:rowIndex withObject:o];
-   }
-   else
-   {
-      MyImageAlignerSquareV3 *square
-         = [[[MyImageAlignerSquareV3 alloc] init] autorelease];
-
-      square->_alignOrigin = r.origin;
-      square->_alignSize = r.size;
-
-      if ( rowIndex < nSquares )
-         [listParams->_alignSquares replaceObjectAtIndex:rowIndex
-                                              withObject:square];
+      
+      else if ( [columnId isEqualToString:@"x"] )
+         r.origin.x = [anObject intValue];
+      
+      else if ( [columnId isEqualToString:@"y"] )
+         r.origin.y = [anObject intValue];
+      
+      else if ( [columnId isEqualToString:@"size"] )
+      {
+         r.size.width = [anObject intValue];
+         r.size.height = r.size.width;
+      }
+      
       else
-         [listParams->_alignSquares addObject:square];
+         NSAssert( NO, @"Unexpected table view column in setObjectValue" );
+      
+      if ( params != nil &&
+          [params isMemberOfClass:[MyImageAlignerImageParametersV3 class]] )
+      {
+         MyImageAlignerOriginV3 *o
+         = [[[MyImageAlignerOriginV3 alloc] init] autorelease];
+         
+         o->_alignOrigin = r.origin;
+         
+         [params->_alignSquares replaceObjectAtIndex:rowIndex withObject:o];
+      }
+      else
+      {
+         MyImageAlignerSquareV3 *square
+         = [[[MyImageAlignerSquareV3 alloc] init] autorelease];
+         
+         square->_alignOrigin = r.origin;
+         square->_alignSize = r.size;
+         
+         if ( rowIndex < nSquares )
+            [listParams->_alignSquares replaceObjectAtIndex:rowIndex
+                                                 withObject:square];
+         else
+            [listParams->_alignSquares addObject:square];
+      }
+      
+      if ( params == nil ||
+          [params isMemberOfClass:[MyImageAlignerImageParametersV3 class]] )
+         dest = item;
+      else
+         dest = _list;
+      [dest setProcessingParameter:params
+                           withRef:myImageAlignerParametersRef
+                     forProcessing:myImageAlignerRef];
    }
-
-   if ( params == nil ||
-        [params isMemberOfClass:[MyImageAlignerImageParametersV3 class]] )
-      dest = item;
-   else
-      dest = _list;
-   [dest setProcessingParameter:params
-                        withRef:myImageAlignerParametersRef
-                  forProcessing:myImageAlignerRef];
 }
 
 @end
