@@ -3,7 +3,7 @@
 //  $Id$
 //
 //  Created by Jean-Etienne LAMIAUD on Sat Jun 9 2007.
-//  Copyright (c) 2007-2023. Jean-Etienne LAMIAUD
+//  Copyright (c) 2007-2025. Jean-Etienne LAMIAUD
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -779,15 +779,18 @@ static NSMutableDictionary *monitorDictionary = nil;
       MyImageAnalyzerResult *res =
                    [item getProcessingParameterWithRef:myImageAnalyzerResultRef
                                          forProcessing:myImageAnalyzerRef];
-      if ( selectThreshold >= _qualityThreshold )
+      if (res != nil)
       {
-         if ( res->_quality < selectThreshold )
-            [item setSelected:NO];
-      }
-      else
-      {
-         if ( res->_quality >= selectThreshold )
-            [item setSelected:YES];
+         if ( selectThreshold >= _qualityThreshold )
+         {
+            if ( res->_quality < selectThreshold )
+               [item setSelected:NO];
+         }
+         else
+         {
+            if ( res->_quality >= selectThreshold )
+               [item setSelected:YES];
+         }
       }
       numImages++;
       if ( [item getSelectionState] == NSOnState )
@@ -910,7 +913,9 @@ static NSMutableDictionary *monitorDictionary = nil;
       _imageUpdate = [defaults boolForKey:K_PREF_ANALYSIS_IMAGE_UPDATING];
 
       // Get an enumerator on the images
-      NSEnumerator *strider = [_list imageEnumerator];
+      NSEnumerator *strider = [_list imageEnumeratorStartAt:nil
+                                                directSense:YES
+                                             skipUnselected:YES];
 
       // Ask the doc to analyse
       [_document startProcess:[MyImageAnalyzer class] withEnumerator:strider
