@@ -3,7 +3,7 @@
 //  $Id$
 //
 //  Created by Jean-Etienne LAMIAUD on Fri Nov 28 2003.
-//  Copyright (c) 2003-2023. Jean-Etienne LAMIAUD
+//  Copyright (c) 2003-2025. Jean-Etienne LAMIAUD
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -963,17 +963,16 @@ typedef struct
 
       // Expand father (won't do anything if already expanded)
       if ( parent != nil )
-	 [_textView expandItem:parent];
+         [_textView expandItem:parent];
 
       row = [_textView rowForItem:item];
 
       // Don't change highlight if item is not in the list
       if ( row < 0 )
-	 return;
+         return;
 
       // Set the hilight
-      [_textView selectRowIndexes:[NSIndexSet indexSetWithIndex:row]
-             byExtendingSelection:NO];
+      [_textView selectRowIndexes:[NSIndexSet indexSetWithIndex:row] byExtendingSelection:NO];
       [_textView scrollRowToVisible:row];
    }
 }
@@ -1582,16 +1581,16 @@ typedef struct
       NSMutableArray *unsortedItems = [NSMutableArray array];
       NSEnumerator *listEnum = [_currentList imageEnumerator];
       MyImageListItem *item;
-
+      
       while ((item = [listEnum nextObject]) != nil)
          [unsortedItems addObject:item];
-
+      
       if (_sortedItems != nil)
          [_sortedItems release];
       if (desc != nil)
       {
          _sortedItems = [unsortedItems sortedArrayUsingComparator: ^(id obj1, id obj2) {
-
+            
             NSObject <LynkeosProcessingParameter> *param1 =
             [obj1 getProcessingParameterWithRef:desc->_parameterReference
                                   forProcessing:desc->_processingRef];
@@ -1603,7 +1602,7 @@ typedef struct
                field1 = objectFromNSValue([param1 valueForKey:desc->_fieldName]);
             if (param2 != nil)
                field2 = objectFromNSValue([param2 valueForKey:desc->_fieldName]);
-
+            
             if (field1 == nil)
             {
                if (field2 == nil)
@@ -1651,11 +1650,14 @@ typedef struct
       else
          // Best effort...
          _sortedItems = unsortedItems;
-
+      
       [_sortedItems retain];
    }
-
+   
    [_textView reloadData];
+
+   // Make sure the selection follows the currently selected item
+   [self highlightItem:_highlightedItem];
 }
 
 - (void) reloadItem:(id<LynkeosProcessableItem>)item
