@@ -22,6 +22,7 @@
 
 #include <math.h>
 
+#include <LynkeosCore/LynkeosAlertPanel.h>
 #include "MyUserPrefsController.h"
 #include "MyImageListItem.h"
 #include "MyGeneralPrefs.h"
@@ -361,6 +362,7 @@ static NSString * const K_STACK_NAME = @"name";
          {
             case ImageMode: modeString= @"Image"; break;
             case DarkFrameMode: modeString= @"Dark frame"; break;
+            case FlatDarkMode:modeString= @"Flat dark"; break;
             case FlatFieldMode:modeString= @"Flat field"; break;
             default:NSAssert(NO,@"Invalid stak mode");
          }
@@ -370,18 +372,29 @@ static NSString * const K_STACK_NAME = @"name";
                               withRef:myImageListItemRef
                         forProcessing:myImageListItemRef];
 
-         // If it is a calibration frame, update the image list
-         if ( mode == FlatFieldMode || mode == DarkFrameMode )
+         // If it is a calibration frame, update the relevant image list
+         if ( mode != ImageMode )
          {
             NSString *ref = nil;
+            id <LynkeosImageList> imageList = nil;
 
             switch( mode )
             {
-               case DarkFrameMode: ref = myImageListItemDarkFrame; break;
-               case FlatFieldMode: ref = myImageListItemFlatField; break;
+               case DarkFrameMode:
+                  ref = myImageListItemDarkFrame;
+                  imageList = [_document imageList];
+                  break;
+               case FlatDarkMode:
+                  ref = myImageListItemDarkFrame;
+                  imageList = [_document flatFieldList];
+                  break;
+               case FlatFieldMode:
+                  ref = myImageListItemFlatField;
+                  imageList = [_document imageList];
+                  break;
                default: break; // Impossible
             }
-            [[_document imageList] setProcessingParameter:[list getImage]
+            [imageList setProcessingParameter:[list getImage]
                                                   withRef:ref
                                             forProcessing:nil];
          }
@@ -501,13 +514,15 @@ static NSString * const K_STACK_NAME = @"name";
    [_doubleSizeCheckBox setEnabled:(data == ListData && mode == ImageMode)];
    [_monochromeCheckBox setEnabled:(data == ListData && mode == FlatFieldMode
                                     && [[list imageArray] count] != 0)];
-   [_normalizeCheckBox setEnabled:(data == ListData && mode == ImageMode)];
+   [_normalizeCheckBox setEnabled:(data == ListData
+                                   && (mode == ImageMode || mode == FlatFieldMode))];
 
    Stack_Mode_t s_mode = (params->_stackMethod != Stacking_Calibration
                           ? params->_stackMethod
                           : Stacking_Standard);
    [_methodPopup selectItemWithTag:s_mode];
-   [_methodPopup setEnabled:(data == ListData && mode == ImageMode)];
+   [_methodPopup setEnabled:(data == ListData
+                             && (mode == ImageMode || mode == FlatFieldMode))];
    [_methodPane selectTabViewItemAtIndex:s_mode];
    switch ( params->_stackMethod )
    {
@@ -595,7 +610,7 @@ static NSString * const K_STACK_NAME = @"name";
 + (unsigned int) authorizedModesForConfig:(id <NSObject>)config
 {
    NSAssert( config == nil, @"Image stacker does not support configuration" );
-   return(ImageMode|DarkFrameMode|FlatFieldMode|ListData|ResultData);
+   return(ImageMode|DarkFrameMode|FlatDarkMode|FlatFieldMode|ListData|ResultData);
 }
 
 + (unsigned int) allowedDisplaysForConfig:(id <NSObject>)config
@@ -901,8 +916,7 @@ static NSString * const K_STACK_NAME = @"name";
 
 - (IBAction) stackAction :(id)sender
 {
-   NSAssert( [_document dataMode] == ListData,
-             @"Stacking started in result mode" );
+   NSAssert( [_document dataMode] == ListData, @"Stacking started in result mode" );
    id <LynkeosImageList> list = [_document currentList];
    MyImageStackerParameters *params=
                  [list getProcessingParameterWithRef:myImageStackerParametersRef
@@ -919,15 +933,26 @@ static NSString * const K_STACK_NAME = @"name";
    {
       // Check for possibly missing calibration frame
       id <LynkeosImageList> dark = [_document darkFrameList],
+                            flatDark = [_document flatDarkList],
                             flat = [_document flatFieldList];
-      if ( mode == ImageMode &&
-           ( ( [[dark imageArray] count] != 0 
-               && [list getProcessingParameterWithRef:myImageListItemDarkFrame
-                                        forProcessing:nil] == nil )
-             ||
-             ( [[flat imageArray] count] != 0 
-               && [list getProcessingParameterWithRef:myImageListItemFlatField
-                                        forProcessing:nil] == nil ) ) )
+      id <LynkeosProcessingParameter> darkImage
+         = [list getProcessingParameterWithRef:myImageListItemDarkFrame forProcessing:nil];
+      id <LynkeosProcessingParameter> flatDarkImage
+         = [flat getProcessingParameterWithRef:myImageListItemDarkFrame forProcessing:nil];
+      id <LynkeosProcessingParameter> flatImage
+         = [list getProcessingParameterWithRef:myImageListItemFlatField forProcessing:nil];
+
+      if ( ( mode == ImageMode &&
+             ( ( [[dark imageArray] count] != 0 && darkImage == nil )
+               ||
+               ( [[flat imageArray] count] != 0
+                 && ( flatImage == nil
+                      || ( [[flatDark imageArray] count] != 0 && flatDarkImage == nil ) ) )
+              ) )
+           ||
+           ( mode == FlatFieldMode &&
+             [[flatDark imageArray] count] != 0 && flatDarkImage == nil )
+         )
       {
          if ( NSAlertDefaultReturn !=
               NSRunAlertPanel(NSLocalizedString(@"CalibrationNotReadyTitle",
@@ -990,11 +1015,13 @@ static NSString * const K_STACK_NAME = @"name";
             }
             break;
          case DarkFrameMode:
+         case FlatDarkMode:
             params->_stackMethod = Stacking_Calibration;
             params->_postStack = MeanStack;
             break;
          case FlatFieldMode:
-            params->_stackMethod = Stacking_Calibration;
+            if (params->_stackMethod == Stacking_Standard)
+               params->_stackMethod = Stacking_Calibration;
             params->_postStack = NormalizeStack;
             break;
          default:
@@ -1007,8 +1034,7 @@ static NSString * const K_STACK_NAME = @"name";
                                                    K_PREF_STACK_IMAGE_UPDATING];
 
       // Temporary parameter to signal the list
-      MyImageStackerList *docParam = [[[MyImageStackerList alloc] init]
-                                                                   autorelease];
+      MyImageStackerList *docParam = [[[MyImageStackerList alloc] init] autorelease];
       docParam->_list = list;
 
       // Get an enumerator on the images
