@@ -3,7 +3,7 @@
 //  $Id$
 //
 //  Created by Jean-Etienne LAMIAUD on 03/01/11.
-//  Copyright 2011-2023 Jean-Etienne LAMIAUD. All rights reserved.
+//  Copyright 2011-2025 Jean-Etienne LAMIAUD. All rights reserved.
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -37,11 +37,11 @@ static NSString * const mySigmaRejectImageStackerResult
 @public
    LynkeosImageBuffer* _sum;          //!< Sum (all passes)
    LynkeosImageBuffer* _sum2;         //!< square sum
-   u_short                     _nStacked;     //!< Number of images in pass 1
+   u_short             _nStacked;     //!< Number of images in pass 1
    LynkeosImageBuffer* _mean;         //!< Mean pixel value
    LynkeosImageBuffer* _sigma;        //!< Standard deviation
-   u_short*                    _count;        //!< Buffer of pixels count during pass2
-   NSConditionLock*            _syncLock;     //!< Synchronisation barrier
+   u_short*            _count;        //!< Buffer of pixels count during pass2
+   NSConditionLock*    _syncLock;     //!< Synchronisation barrier
 }
 @end
 
@@ -146,13 +146,9 @@ static NSString * const mySigmaRejectImageStackerResult
       if (res->_sum != nil)
       {
          REAL s = 1.0/(REAL)res->_nStacked;
-         double vmin, vmax;
-         REAL MinSigma;
          [res->_sum multiplyWithScalar:s];
          res->_mean = res->_sum;
          res->_sum = nil;
-         [res->_mean getMinLevel:&vmin maxLevel:&vmax];
-         MinSigma = (vmax - vmin)/1000.0;
 
          // The variance
          if (res->_sum2 != nil)
@@ -172,10 +168,12 @@ static NSString * const mySigmaRejectImageStackerResult
                   for( x = 0; x < res->_sum2->_w; x++ )
                   {
                      REAL v = stdColorValue(res->_sum2, x, y, c);
-                     if (v >= MinSigma*MinSigma)
+                     if (v >= FLT_EPSILON*FLT_EPSILON)
                         v = sqrt(v);
                      else
-                        v = MinSigma;
+                     {
+                        v = FLT_EPSILON; // Enforce a minimum sigma in case of floating point issue
+                     }
                      SET_SAMPLE(p[c], x, y, res->_sum2->_padw, v);
                   }
             res->_sigma = res->_sum2;
@@ -368,15 +366,18 @@ static NSString * const mySigmaRejectImageStackerResult
       else
          [res->_sum add:_sum];
 
-      if ( res->_count == NULL )
-         res->_count = (u_short*)calloc(_sum->_nPlanes*_sum->_w*_sum->_h,
-                                        sizeof(u_short));
+      if (_count != NULL)
+      {
+         if ( res->_count == NULL )
+            res->_count = (u_short*)calloc(_sum->_nPlanes*_sum->_w*_sum->_h,
+                                           sizeof(u_short));
 
-      for( c = 0; c < _sum->_nPlanes; c++ )
-         for( y = 0; y < _sum->_h; y++ )
-            for( x = 0; x < _sum->_w; x++ )
-               res->_count[(c*_sum->_h + y)*_sum->_w + x] +=
-                                          _count[(c*_sum->_h + y)*_sum->_w + x];
+         for( c = 0; c < _sum->_nPlanes; c++ )
+            for( y = 0; y < _sum->_h; y++ )
+               for( x = 0; x < _sum->_w; x++ )
+                  res->_count[(c*_sum->_h + y)*_sum->_w + x] +=
+                  _count[(c*_sum->_h + y)*_sum->_w + x];
+      }
 
       [_sum release];
       _sum = nil;
@@ -393,7 +394,7 @@ static NSString * const mySigmaRejectImageStackerResult
       [list getProcessingParameterWithRef:mySigmaRejectImageStackerResult
                             forProcessing:myImageStackerRef];
 
-   if (res->_sum != nil)
+   if (res->_sum != nil && res->_count != NULL)
    {
       // Compute the second pass mean, and store it
       p = (REAL**)[res->_sum colorPlanes];
