@@ -337,9 +337,9 @@ static const double MM_LN_10 = -M_LN10;
    [_blackWhiteSlider setEnabled:NO];
    [_gammaText setEnabled:NO];
    [_gammaSlider setEnabled:NO];
-   [_blackText setStringValue:@""];
-   [_whiteText setStringValue:@""];
-   [_gammaText setStringValue:@""];   
+   [_blackText setDoubleValue:0.0];
+   [_whiteText setDoubleValue:255.0];
+   [_gammaText setDoubleValue:1.0];
 }
 
 // Image and zoom
@@ -600,9 +600,10 @@ static const double MM_LN_10 = -M_LN10;
    }
    else
    {
-      [_blackText setStringValue:@""];
-      [_whiteText setStringValue:@""];
-      [_gammaText setStringValue:@""];
+      // Provide default values
+      [_blackText setDoubleValue:0.0];
+      [_whiteText setDoubleValue:255.0];
+      [_gammaText setDoubleValue:1.0];
    }
 
    [self applyZoom:_zoom from:nil withRedraw:YES];
