@@ -3,7 +3,7 @@
 //  $Id$
 //
 //  Created by Jean-Etienne LAMIAUD on Sat Nov 01 2003.
-//  Copyright (c) 2003-2020. Jean-Etienne LAMIAUD
+//  Copyright (c) 2003-2023. Jean-Etienne LAMIAUD
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -533,7 +533,7 @@ static short processDrag( long mouse, u_short origin, u_short maximum,
 {
    // Act on current selection, except if shift was pressed to add a new selection
    _modifiers = (unsigned int)[theEvent modifierFlags];
-   if (_selectionMode == MultiSelection && (_modifiers & NSShiftKeyMask) != 0)
+   if (_selectionMode == MultiSelection && (_modifiers & NSEventModifierFlagShift) != 0)
    {
       _previousSelectionIndex = _currentSelectionIndex;
       _currentSelectionIndex = [_selection count];
