@@ -236,7 +236,7 @@
  */
 - (void) getImageSample:(REAL * const * const)sample
              withPlanes:(u_short)nPlanes
-                    atX:(u_short)x Y:(u_short)y W:(u_short)w H:(u_short)h
+                    atX:(short)x Y:(short)y W:(u_short)w H:(u_short)h
               lineWidth:(u_short)lineW
 {
    const u_short imagePlanes = [self numberOfPlanes];
@@ -250,7 +250,7 @@
               @"Illegal transfer from %d planes to %d planes", 
              imagePlanes, nPlanes );
 
-   NSAssert( x+w <= _width && y+h <= _height, 
+   NSAssert( x+w <= (short)_width && y+h <= (short)_height, 
              @"Sample at least partly outside the image" );
 
    buf = _TIFFmalloc(TIFFStripSize(tiff));
