@@ -3,7 +3,7 @@
 //  $Id: $
 //
 //  Created by Jean-Etienne LAMIAUD on Tue May 24 2022.
-//  Copyright (c) 2022-2023. Jean-Etienne LAMIAUD
+//  Copyright (c) 2022-2025. Jean-Etienne LAMIAUD
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -39,7 +39,7 @@
 @end
 
 @implementation SER_RAW_Reader
-
+#warning Replace the SER_Image_Buffer by a BayerImageBuffer
 + (void) load  // Only to force the runtime to load the class
 {
 }
@@ -369,7 +369,7 @@
       [_darkFrame release];
       _darkFrame = nil;
    }
-   NSAssert(dark == nil || _mode == ImageMode || _mode == UnsetListMode,
+   NSAssert(dark == nil || _mode == ImageMode || _mode == UnsetListMode || _mode == FlatFieldMode,
             @"Bad reader mode to set dark frame %d", _mode);
    NSAssert(dark == nil || [dark isKindOfClass:[SER_ImageBuffer class]],
             @"SER dark frame is not in SER format");
